# Generated by roxygen2: do not edit by hand

S3method(print,reactRouter)
export(Await)
export(BrowserRouter)
export(Form)
export(HashRouter)
export(JS)
export(Link)
export(Link.shinyInput)
export(MemoryRouter)
export(NavLink)
export(NavLink.shinyInput)
export(Navigate)
export(Outlet)
export(Route)
export(RouterProvider)
export(Routes)
export(ScrollRestoration)
export(createBrowserRouter)
export(createHashRouter)
export(createMemoryRouter)
export(createRoutesFromElements)
export(dataResponse)
export(isRouteErrorResponse)
export(reactRouterDependency)
export(reactRouterExample)
export(redirect)
export(redirectDocument)
export(replaceResponse)
export(updateLink.shinyInput)
export(updateNavLink.shinyInput)
export(useActionData)
export(useAsyncError)
export(useAsyncValue)
export(useBlocker)
export(useFetcher)
export(useFetchers)
export(useHref)
export(useInRouterContext)
export(useLinkClickHandler)
export(useLoaderData)
export(useLocation)
export(useMatch)
export(useMatches)
export(useNavigate)
export(useNavigation)
export(useNavigationType)
export(useOutlet)
export(useOutletContext)
export(useParams)
export(useResolvedPath)
export(useRevalidator)
export(useRouteError)
export(useRouteLoaderData)
export(useRoutes)
export(useSearchParams)
export(useSubmit)
export(useViewTransitionState)
importFrom(shiny.react,JS)
