% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/components.R
\name{component}
\alias{component}
\title{Documentation template for components}
\arguments{
\item{...}{Props to pass to the component.
The allowed props are listed below in the \bold{Details} section.}
}
\value{
Object with `shiny.tag` class suitable for use in the UI of a Shiny app.
}
\description{
Documentation template for components
}
\keyword{internal}
