% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/components.R
\name{ScrollRestoration}
\alias{ScrollRestoration}
\title{ScrollRestoration}
\usage{
ScrollRestoration(...)
}
\arguments{
\item{...}{Props to pass to element. Notable props: \code{getKey} (a
\code{\link{JS}} function to compute the scroll key from the location)
and \code{storageKey} (Character, custom \code{sessionStorage} key).}
}
\value{
A ScrollRestoration component.
}
\description{
\url{https://api.reactrouter.com/v7/functions/react-router.ScrollRestoration.html}
}
\details{
Emulates the browser's scroll restoration on location changes after loaders
have completed. Place once inside the root layout of a data router app.
Requires a data router (\code{\link{createBrowserRouter}},
\code{\link{createHashRouter}}, etc.).
}
