% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RouterProvider.R
\name{createBrowserRouter}
\alias{createBrowserRouter}
\title{createBrowserRouter}
\usage{
createBrowserRouter(...)
}
\arguments{
\item{...}{\code{\link{Route}} elements. Pass directly, or (optionally)
wrapped in \code{\link{createRoutesFromElements}} to mirror the
official React Router v7 API.}
}
\value{
A createBrowserRouter component.
}
\description{
\url{https://api.reactrouter.com/v7/functions/react-router.createBrowserRouter.html}
}
\details{
Creates a browser router using the data router API.
Use with \code{\link{createRoutesFromElements}} and \code{\link{Route}}.
}
